#!/usr/bin/env python

## Clean the event database
#
# This tool will remove all recorded events from the specified event database.
#
# Usage:
#
# $ ./clean_db
#
# This is released under the terms of the BSD license. See COPYRIGHT for
# further information.
#

import os
import sys
import getopt
from eventdb import EventDB

## Perform the clean action
#
def clean_db(eventsDB = 'events.sqlite'):
    db = EventDB(eventsDB)
    db.clean()

## Display usage information
#
def usage(progName):
    print >>sys.stderr, "clean_db v0.1"
    print >>sys.stderr, "Usage:\n"
    print >>sys.stderr, "  %s [option]" % progName
    print >>sys.stderr, ""
    print >>sys.stderr, "  --events-db events.sl3   Use events.sl3 as the source for the heatmap data."
    print >>sys.stderr, ""

## Main entry-point
#
def main(argv):
    try:    
        # Parse arguments with getopt
        options, trailer = getopt.getopt(argv[1:], '', ['events-db='])

        # Check for erroneous filenames
        if len(trailer) != 0:
            raise Exception('Unrecognised options "%s"' % str.join(',', trailer))

        fileArgs = {'--events-db': 'eventsDB'}
        args = {}

        # Parse the command-line options
        for option, value in options:
            if option in fileArgs:
                
                # Extract the parameter name
                param = fileArgs[option]
                if not os.path.isfile(value):
                    raise Exception('%s is not a file.' % value)

                args[param] = value
            else:
                raise Exception('Unknown option "%s".' % option)

        clean_db(**args)

    except Exception, e:
        print >>sys.stderr, "Error: %s" % e.message
        print >>sys.stderr, ""
        usage(argv[0])
        exit(1)


# If we're being run as a stand-alone script, fire off main().
#
if __name__ == '__main__':
    main(sys.argv)

