#!/usr/bin/env python

## Import an Exim4 log's rejected spam events into the event database
#
# This script has been designed primarily for those using Debian's sa-exim
# package, to capture the rejected message events for plotting onto a 
# geographic heatmap.
#
# You can point this script at one or more exim4 log files, either in 
# plain text format, or gzipped. Each line will be scanned for the text
# "rejected by local_scan", and if found, the IP address on the line 
# will be recorded in the events database.
#
# After running this log analysis, you should run generate_heatmap.py to
# analyse the events. Existing events in the database will not be cleaned
# before more are added; you must explicitly flush the event database.
#
#
# Usage:
#
# $ ./clean_db
# $ ./import_exim4 /var/log/exim4/mainlog*
# $ ./generate_heatmap spam_map.png
#
# This is released under the terms of the BSD license. See COPYRIGHT for
# further information.
#

import sys
import re

from eventdb import EventDB
from parser import open_logfile, parser_main

## Import rejections from an exim4 log file into the events database
#
def import_exim4(logfiles, eventsDB = 'events.sqlite'):
    try:
        db = EventDB(eventsDB)

        for filename in logfiles:   
            logfile = open_logfile(filename)

            # Regular expression to extract the remote host address
            re_ip = re.compile('H=[^=]*\[(([0-9]+\.){3}[0-9]+)\]')

            for line in logfile:
                # Only care about things where spamassassin rejects it
                if line.find('rejected by local_scan') != -1:

                    # Try to grab the IP for the remote host
                    matches = re_ip.search(line)
                    if matches != None:
                        db.addEvent(matches.group(1))

    except IOError, e:
        print >>sys.stderr, "Could not import log file %s." % filename


## Display usage information
#
def usage(progName):
    print >>sys.stderr, "import_exim4 v0.1"
    print >>sys.stderr, "Usage:\n"
    print >>sys.stderr, "  %s [option] ... /var/log/exim4/mainlog [logfile2 ...]" % progName
    print >>sys.stderr, ""
    print >>sys.stderr, "  --events-db events.sl3   Use events.sl3 as the source for the heatmap data."
    print >>sys.stderr, ""


## Main entry-point when called as a script
#
def main(argv):
    parser_main(argv, import_exim4, usage)


# If run as a standalone app, behave accordingly.
#
if __name__ == '__main__':
    main(sys.argv)

